/* 
* Based on: 
* Arduino Wireless Communication Tutorial Example 1 - Transmitter Code by Dejan Nedelkovski, www.HowToMechatronics.com
*/

#include <SPI.h>            // used for radio
#include <nRF24L01.h>       // used for radio
#include <RF24.h>           // used for radio
#include <Wire.h>           // used for both
#include "I2Cdev.h"         // used for accelerometer MPU 6050
#include "MPU6050.h"        // used for accelerometer MPU 6050

//radio setup
RF24 radio(7, 8); // CE, CSN
const byte address[6] = "00001";

//accelerometer setup
MPU6050 mpu;                // init of accelerometer object
int16_t ax, ay, az;
int16_t gx, gy, gz;
int axisX, axisY, axisZ;

//photoresistor setup
const int sensorPin = 0;
//const int ledPin = 9;
int lightCal;
int lightVal;
int speedEng;

struct Data_Package
{
  byte engSpeed;
  byte serAngle;
  byte windBlow;    // wip
};
Data_Package data;

void setup() 
{
  
  Serial.begin(9600);
  Wire.begin();
  mpu.initialize();
  
  // Start radio communication:
  radio.begin();  //start radio object
  //radio.openWritingPipe(address);
  radio.setPALevel(RF24_PA_MIN); //type of connection, if higher level add capacitor
  //radio.setDataRate(RF24_2MBPS);
  //radio.setChannel(124);
  radio.openWritingPipe(address);
  radio.stopListening();

  //pinMode(ledPin, OUTPUT);
  lightCal = analogRead(sensorPin);
  Serial.println(lightCal);

  // Data setup - initial values:
  data.engSpeed = 0;  // init speed 0 to make it easier (range 0 to 255)
  data.serAngle = 127;  // init position of the steering wheel also 0 (0 to 255, 127 is middle)
  data.windBlow = 0;  // init blow of air set to 0  (range 0 to 255)
  
}

void loop() 
{
  // Data setup - read the analog inputs and convert them into digestable thing
  // Precalc
  mpu.getMotion6(&ax, &ay, &az, &gx, &gy, &gz);
  axisX = map(ax, -17000, 17000, 0, 360 ); // X axis data // tilt 2 ?
  axisY = map(ay, -17000, 17000, 0, 360);  // Y axis data // tilt 1
  axisZ = map(az, -17000, 17000, 0, 360);  // Z axis data

  lightVal = analogRead(sensorPin);             // photoresistor setup
    
  // Data setup - assigning
  data.engSpeed = map(lightVal,100,1000, 20, 250);
  data.serAngle = map(axisY,0,360,0,255);   
  data.windBlow = map(axisZ,0,360,0,255);

  Serial.print("Speed = ");
  Serial.print(data.engSpeed);
  Serial.print(" Angle = ");
  Serial.print(data.serAngle);
  //Serial.print(" Wind = ");
  //Serial.print(data.windBlow);
  Serial.println("");
  
  //SENDING:
  radio.stopListening();                        // idk i guess needed to transmit
  /*
  lightVal = analogRead(sensorPin);
    //Serial.println(lightVal);
  //speedEng = map(lightVal,0, 1023, 0, 255);   // original basic remap - values too normal
  speedEng = map(lightVal,100,1000, 20, 250);   // remaping the values from light - values tweaked
  Serial.println(speedEng);                     // to see what will be sent
  */
  //radio.write(&speedEng,sizeof(speedEng));      // actual transmission
  radio.write(&data,sizeof(Data_Package));      // actual transmission
  
  //radio.stopListening();

  //WIP
  //Now listen to response
}
